summaryrefslogtreecommitdiff
path: root/examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py')
-rw-r--r--examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py72
1 files changed, 39 insertions, 33 deletions
diff --git a/examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py b/examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py
index e83e0d2..84b9105 100644
--- a/examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py
+++ b/examples/v3arch/asyncore/oneliner/manager/cmdgen/get-v3-table-object-by-index.py
@@ -1,35 +1,41 @@
-#
-# Command Generator
-#
-# Send SNMP GET request using the following options:
-#
-# * with SNMPv3, user 'usr-none-none', no authentication, no privacy
-# * over IPv4/UDP
-# * to an Agent at demo.snmplabs.com:161
-# * for IF-MIB::ifInOctets.1 MIB object
-# * perform response OIDs and values resolution at MIB
-#
+"""
+GET table row
++++++++++++++
+
+Send SNMP GET request using the following options:
+
+* with SNMPv3, user 'usr-none-none', no authentication, no privacy
+* over IPv4/UDP
+* to an Agent at demo.snmplabs.com:161
+* for IF-MIB::ifInOctets.1 and IF-MIB::ifOutOctets.1 MIB object
+* perform response OIDs and values resolution at MIB
+
+Functionally similar to:
+
+| $ snmpget -v3 -l authPriv -u usr-md5-des -A authkey1 -X privkey1 \
+| demo.snmplabs.com \
+| IF-MIB::ifInOctets.1 IF-MIB::ifOutOctets.1
+
+"""#
from pysnmp.entity.rfc3413.oneliner.cmdgen import *
-for errorIndication, \
- errorStatus, errorIndex, \
- varBinds in getCmd(SnmpEngine(),
- UsmUserData('usr-none-none'),
- UdpTransportTarget(('demo.snmplabs.com', 161)),
- ContextData(),
- ObjectType(ObjectIdentity('IF-MIB', 'ifInOctets', 1)),
- lookupNames=True, lookupValues=True):
- # Check for errors and print out results
- if errorIndication:
- print(errorIndication)
- else:
- if errorStatus:
- print('%s at %s' % (
- errorStatus.prettyPrint(),
- errorIndex and varBinds[int(errorIndex)-1][0] or '?'
- )
- )
- else:
- for varBind in varBinds:
- print(' = '.join([ x.prettyPrint() for x in varBind ]))
- break
+errorIndication, errorStatus, errorIndex, varBinds = next(
+ getCmd(SnmpEngine(),
+ UsmUserData('usr-none-none'),
+ UdpTransportTarget(('demo.snmplabs.com', 161)),
+ ContextData(),
+ ObjectType(ObjectIdentity('IF-MIB', 'ifInOctets', 1)),
+ ObjectType(ObjectIdentity('IF-MIB', 'ifOutOctets', 1)))
+)
+
+if errorIndication:
+ print(errorIndication)
+elif errorStatus:
+ print('%s at %s' % (
+ errorStatus.prettyPrint(),
+ errorIndex and varBinds[int(errorIndex)-1][0] or '?'
+ )
+ )
+else:
+ for varBind in varBinds:
+ print(' = '.join([ x.prettyPrint() for x in varBind ]))